#include <plib.h>
#include "NU32v2.h"
#include "Nokia5110.h"

int main(void) {
  int i = 2;
  float y[40];
  int yi[40];
  char str[5];

  SYSTEMConfig(SYS_FREQ, SYS_CFG_ALL);

  // configure for multi-vectored mode
  INTConfigureSystem(INT_SYSTEM_CONFIG_MULT_VECTOR);

  // enable multi-vector interrupts 
  INTEnableSystemMultiVectoredInt(); 

  // initialize serial port and interrupt
  initSerialNU32v2();
  initLEDs(); 	// set LED pins as outputs
  LED0 = 1;
  LED1 = 0;

  // init and clear the LCD
  LcdInitialize();
  LcdClear();

  // write to the PC
  WriteString(UART3, "\r\nHello World!\r\n");

  // make and plot one wavelength of a sine wave
  for (i=0;i<40;i++) {
    y[i] = 10.0+10.0*sin(0.157*i);
    yi[i] = (int)y[i];
    setPixel(i+43,18+yi[i],1); // draw one pixel
  }

  // write some characters and strings
  gotoXY(0,1);
  LcdString("1 Test1");
  gotoXY(0,0);
  LcdString("012345678901");
  gotoXY(0,2);
  LcdString("2");
  gotoXY(0,3);
  LcdString("3");
  gotoXY(0,4);
  LcdString("4");
  gotoXY(0,5);
  LcdString("5");

  // write the value of a variable
  gotoXY(10,5);
  sprintf(str, "i=%d", i);
  LcdString(str);

  LED0 = 0;
  LED1 = 1;

  while(1) {
    // nothing, use the ISR to echo any bytes recieved
    // and clear the LCD if an 'a' is received
  }

  return 0;
} // end main

// UART3 interrupt handler, priority level 2
void __ISR(_UART_3_VECTOR, ipl2) IntUart3Handler(void) {
  // Is this an RX interrupt?
  if(INTGetFlag(INT_SOURCE_UART_RX(UART3))){
    char data = UARTGetDataByte(UART3);

    // Echo what we just received
    PutCharacter(UART3, data); 

    // do something with the data
    if(data =='a') {
      // do something
      LcdClear();
    }

    // Clear the RX interrupt Flag
    INTClearFlag(INT_SOURCE_UART_RX(UART3)); 
  }

  // We don't care about TX interrupt
  if(INTGetFlag(INT_SOURCE_UART_TX(UART3))) {
    INTClearFlag(INT_SOURCE_UART_TX(UART3));
  }
}
